==> Products.TinyMCE-1.1rc11.zip: Products.TinyMCE-1.1rc11/Products/TinyMCE/skins/tinymce/langs/tr.js <==
tinyMCE.addI18n({tr:{
common:{
edit_confirm:"Metin giri\u015Fi i\u00E7in WYSIWYG modunu kullanmak ister misiniz?",
apply:"Uygula",
insert:"Ekle",
update:"G\u00FCncelle",
cancel:"\u0130ptal",
close:"Kapat",
browse:"G\u00F6zat",
class_name:"S\u0131n\u0131f",
not_set:"-- Ayarlanmad\u0131 --",
clipboard_msg:"Mozilla Firefox da Kes/Kopyala/Yap\u0131\u015Ft\u0131r \u00F6zelli\u011Fi kullan\u0131lmamaktad\u0131r. \nBu konu hakk\u0131nda bilgi almak ister misiniz?",
clipboard_no_support:"\u015Eu an kulland\u0131\u011F\u0131n\u0131z taray\u0131c\u0131n\u0131z klavye k\u0131sayollar\u0131n\u0131 desteklememektedir.",
popup_blocked:"\u00DCzg\u00FCn\u00FCz, a\u00E7\u0131l\u0131r pencere engelleyiciniz uygulama i\u00E7in gerekli bir pencereyi engelledi. Bu arac\u0131 tam olarak kullanabilmek i\u00E7in a\u00E7\u0131l\u0131r pencere engelleyicisini kapat\u0131n\u0131z.",
invalid_data:"Hata: Invalid values entered, these are marked in red.",
more_colors:"Daha fazla renk"
},
contextmenu:{
align:"Hizalama",
left:"Sol",
center:"Orta",
right:"Sa\u011F",
full:"Tam"
},
insertdatetime:{
date_fmt:"%d-%m-%Y",
time_fmt:"%H:%M:%S",
insertdate_desc:"Tarih ekle",
inserttime_desc:"Saat ekle",
months_long:"Ocak,\u015Eubat,Mart,Nisan,May\u0131s,Haziran,Temmuz,A\u011Fustos,Eyl\u00FCl,Ekim,Kas\u0131m,Aral\u0131k",
months_short:"Oca,\u015Eub,Mar,Nis,May,Haz,Tem,A\u011Fu,Eyl,Eki,Kas,Ara",
day_long:"Pazar,Pazartesi,Sal\u0131,\u00C7ar\u015Famba,Per\u015Fembe,Cuma,Cumartesi",
day_short:"Paz,Pzt,Sal,\u00C7r\u015F,Per,Cum,Cts"
},
print:{
print_desc:"Yazd\u0131r"
},
preview:{
preview_desc:"\u00D6nizleme"
},
directionality:{
ltr_desc:"Sa\u011Fdan sola y\u00F6nlendir",
rtl_desc:"Soldan sa\u011Fa y\u00F6nlendir"
},
layer:{
insertlayer_desc:"Yeni katman ekle",
forward_desc:"\u00D6ne getir",
backward_desc:"Arkaya al",
absolute_desc:"Mutlaka konumu de\u011Fi\u015Ftir",
content:"Yeni katman..."
},
save:{
save_desc:"Kaydet",
cancel_desc:"T\u00FCm de\u011Fi\u015Fiklikleri iptal et"
},
nonbreaking:{
nonbreaking_desc:"B\u00F6l\u00FCnemez bo\u015Fluk karakteri ekle"
},
iespell:{
iespell_desc:"\u0130mla kontrol\u00FCn\u00FC ba\u015Flat",
download:"ieSpell bulunamad\u0131. \u015Eimdi kurmak ister misiniz?"
},
advhr:{
advhr_desc:"Yatay \u00E7izgi"
},
emotions:{
emotions_desc:"\u0130fadeler"
},
searchreplace:{
search_desc:"Bul",
replace_desc:"Bul/De\u011Fi\u015Ftir"
},
advimage:{
image_desc:"Resim ekle/d\u00FCzenle"
},
advlink:{
link_desc:"Ba\u011Flant\u0131 ekle/d\u00FCzenle"
},
xhtmlxtras:{
cite_desc:"Al\u0131nt\u0131",
abbr_desc:"K\u0131saltma",
acronym_desc:"K\u0131sa ad",
del_desc:"Silme",
ins_desc:"Ekleme",
attribs_desc:"Nitelik ekle/d\u00FCzenle"
},
style:{
desc:"CSS Stilini D\u00FCzenle"
},
paste:{
paste_text_desc:"D\u00FCz metin olarak yap\u0131\u015Ft\u0131r",
paste_word_desc:"Word'den yap\u0131\u015Ft\u0131r",
selectall_desc:"T\u00FCm\u00FCn\u00FC se\u00E7"
},
paste_dlg:{
text_title:"Pencereye metin yap\u0131\u015Ft\u0131rmak i\u00E7in klavyeden CTRL+V i kullan\u0131n.",
text_linebreaks:"Sat\u0131r kesmelerini tut",
word_title:"Pencereye metin yap\u0131\u015Ft\u0131rmak i\u00E7in klavyeden CTRL+V i kullan\u0131n."
},
table:{
desc:"Yeni tablo ekle",
row_before_desc:"\u00DCst\u00FCne sat\u0131r ekle",
row_after_desc:"Alt\u0131na sat\u0131r ekle",
delete_row_desc:"Sat\u0131r sil",
col_before_desc:"Soluna s\u00FCtun ekle",
col_after_desc:"Sa\u011F\u0131na s\u00FCtun ekle",
delete_col_desc:"S\u00FCtun sil",
split_cells_desc:"Birle\u015Ftirilmi\u015F tablo h\u00FCcrelerini b\u00F6l",
merge_cells_desc:"Tablo h\u00FCcrelerini birle\u015Ftir",
row_desc:"Tablo sat\u0131r \u00F6zellikleri",
cell_desc:"Tablo h\u00FCcre \u00F6zellikleri",
props_desc:"Tablo \u00F6zellikleri",
paste_row_before_desc:"\u00DCst\u00FCne tablo sat\u0131r\u0131 yap\u0131\u015Ft\u0131r",
paste_row_after_desc:"Alt\u0131na tablo sat\u0131r\u0131 yap\u0131\u015Ft\u0131r",
cut_row_desc:"Tablo sat\u0131r\u0131n\u0131 kes",
copy_row_desc:"Tablo sat\u0131r\u0131n\u0131 kopyala",
del:"Tablo sil",
row:"Sat\u0131r",
col:"S\u00FCtun",
cell:"H\u00FCcre"
},
autosave:{
unload_msg:"Bu sayfadan \u00E7\u0131karsan\u0131z yapt\u0131\u011F\u0131n\u0131z de\u011Fi\u015Fiklikler kaybolabilir."
},
fullscreen:{
desc:"Tam ekran modunu a\u00E7/kapat"
},
media:{
desc:"T\u00FCmle\u015Fik medya ekle / d\u00FCzenle",
edit:"T\u00FCmle\u015Fik medya d\u00FCzenle"
},
fullpage:{
desc:"Belge \u00F6zellikleri"
},
template:{
desc:"\u00D6ntan\u0131ml\u0131 i\u00E7erik \u015Fablonu kullan"
},
visualchars:{
desc:"G\u00F6rsel karakter kontrol\u00FC a\u00E7\u0131k/kapal\u0131."
},
spellchecker:{
desc:"\u0130mla kontrol\u00FCn\u00FC a\u00E7/kapat",
menu:"\u0130mla kontrol\u00FC ayarlar\u0131",
ignore_word:"S\u00F6zc\u00FC\u011F\u00FC yoksay",
ignore_words:"T\u00FCm\u00FCn\u00FC yoksay",
langs:"Diller",
wait:"L\u00FCtfen bekleyin...",
sug:"\u00D6neriler",
no_sug:"\u00D6neri yok",
no_mpell:"\u0130mla hatas\u0131 bulunamad\u0131."
},
pagebreak:{
desc:"Sayfa sonu ekle."
}}});

==> Products.TinyMCE-1.2.12.zip: Products.TinyMCE-1.2.12/Products/TinyMCE/skins/tinymce/langs/tr.js <==
tinyMCE.addI18n({tr:{
common:{
edit_confirm:"Metin giri\u015Fi i\u00E7in WYSIWYG modunu kullanmak ister misiniz?",
apply:"Uygula",
insert:"Ekle",
update:"G\u00FCncelle",
cancel:"\u0130ptal",
close:"Kapat",
browse:"G\u00F6zat",
class_name:"S\u0131n\u0131f",
not_set:"-- Ayarlanmad\u0131 --",
clipboard_msg:"Mozilla Firefox da Kes/Kopyala/Yap\u0131\u015Ft\u0131r \u00F6zelli\u011Fi kullan\u0131lmamaktad\u0131r. \nBu konu hakk\u0131nda bilgi almak ister misiniz?",
clipboard_no_support:"\u015Eu an kulland\u0131\u011F\u0131n\u0131z taray\u0131c\u0131n\u0131z klavye k\u0131sayollar\u0131n\u0131 desteklememektedir.",
popup_blocked:"\u00DCzg\u00FCn\u00FCz, a\u00E7\u0131l\u0131r pencere engelleyiciniz uygulama i\u00E7in gerekli bir pencereyi engelledi. Bu arac\u0131 tam olarak kullanabilmek i\u00E7in a\u00E7\u0131l\u0131r pencere engelleyicisini kapat\u0131n\u0131z.",
invalid_data:"Hata: Invalid values entered, these are marked in red.",
more_colors:"Daha fazla renk"
},
contextmenu:{
align:"Hizalama",
left:"Sol",
center:"Orta",
right:"Sa\u011F",
full:"Tam"
},
insertdatetime:{
date_fmt:"%d-%m-%Y",
time_fmt:"%H:%M:%S",
insertdate_desc:"Tarih ekle",
inserttime_desc:"Saat ekle",
months_long:"Ocak,\u015Eubat,Mart,Nisan,May\u0131s,Haziran,Temmuz,A\u011Fustos,Eyl\u00FCl,Ekim,Kas\u0131m,Aral\u0131k",
months_short:"Oca,\u015Eub,Mar,Nis,May,Haz,Tem,A\u011Fu,Eyl,Eki,Kas,Ara",
day_long:"Pazar,Pazartesi,Sal\u0131,\u00C7ar\u015Famba,Per\u015Fembe,Cuma,Cumartesi",
day_short:"Paz,Pzt,Sal,\u00C7r\u015F,Per,Cum,Cts"
},
print:{
print_desc:"Yazd\u0131r"
},
preview:{
preview_desc:"\u00D6nizleme"
},
directionality:{
ltr_desc:"Sa\u011Fdan sola y\u00F6nlendir",
rtl_desc:"Soldan sa\u011Fa y\u00F6nlendir"
},
layer:{
insertlayer_desc:"Yeni katman ekle",
forward_desc:"\u00D6ne getir",
backward_desc:"Arkaya al",
absolute_desc:"Mutlaka konumu de\u011Fi\u015Ftir",
content:"Yeni katman..."
},
save:{
save_desc:"Kaydet",
cancel_desc:"T\u00FCm de\u011Fi\u015Fiklikleri iptal et"
},
nonbreaking:{
nonbreaking_desc:"B\u00F6l\u00FCnemez bo\u015Fluk karakteri ekle"
},
iespell:{
iespell_desc:"\u0130mla kontrol\u00FCn\u00FC ba\u015Flat",
download:"ieSpell bulunamad\u0131. \u015Eimdi kurmak ister misiniz?"
},
advhr:{
advhr_desc:"Yatay \u00E7izgi"
},
emotions:{
emotions_desc:"\u0130fadeler"
},
searchreplace:{
search_desc:"Bul",
replace_desc:"Bul/De\u011Fi\u015Ftir"
},
advimage:{
image_desc:"Resim ekle/d\u00FCzenle"
},
advlink:{
link_desc:"Ba\u011Flant\u0131 ekle/d\u00FCzenle"
},
xhtmlxtras:{
cite_desc:"Al\u0131nt\u0131",
abbr_desc:"K\u0131saltma",
acronym_desc:"K\u0131sa ad",
del_desc:"Silme",
ins_desc:"Ekleme",
attribs_desc:"Nitelik ekle/d\u00FCzenle"
},
style:{
desc:"CSS Stilini D\u00FCzenle"
},
paste:{
paste_text_desc:"D\u00FCz metin olarak yap\u0131\u015Ft\u0131r",
paste_word_desc:"Word'den yap\u0131\u015Ft\u0131r",
selectall_desc:"T\u00FCm\u00FCn\u00FC se\u00E7",
plaintext_mode_sticky:"Paste is now in plain text mode. Click again to toggle back to regular paste mode. After you paste something you will be returned to regular paste mode.",
plaintext_mode:"Paste is now in plain text mode. Click again to toggle back to regular paste mode."
},
paste_dlg:{
text_title:"Pencereye metin yap\u0131\u015Ft\u0131rmak i\u00E7in klavyeden CTRL+V i kullan\u0131n.",
text_linebreaks:"Sat\u0131r kesmelerini tut",
word_title:"Pencereye metin yap\u0131\u015Ft\u0131rmak i\u00E7in klavyeden CTRL+V i kullan\u0131n."
},
table:{
desc:"Yeni tablo ekle",
row_before_desc:"\u00DCst\u00FCne sat\u0131r ekle",
row_after_desc:"Alt\u0131na sat\u0131r ekle",
delete_row_desc:"Sat\u0131r sil",
col_before_desc:"Soluna s\u00FCtun ekle",
col_after_desc:"Sa\u011F\u0131na s\u00FCtun ekle",
delete_col_desc:"S\u00FCtun sil",
split_cells_desc:"Birle\u015Ftirilmi\u015F tablo h\u00FCcrelerini b\u00F6l",
merge_cells_desc:"Tablo h\u00FCcrelerini birle\u015Ftir",
row_desc:"Tablo sat\u0131r \u00F6zellikleri",
cell_desc:"Tablo h\u00FCcre \u00F6zellikleri",
props_desc:"Tablo \u00F6zellikleri",
paste_row_before_desc:"\u00DCst\u00FCne tablo sat\u0131r\u0131 yap\u0131\u015Ft\u0131r",
paste_row_after_desc:"Alt\u0131na tablo sat\u0131r\u0131 yap\u0131\u015Ft\u0131r",
cut_row_desc:"Tablo sat\u0131r\u0131n\u0131 kes",
copy_row_desc:"Tablo sat\u0131r\u0131n\u0131 kopyala",
del:"Tablo sil",
row:"Sat\u0131r",
col:"S\u00FCtun",
cell:"H\u00FCcre"
},
autosave:{
unload_msg:"Bu sayfadan \u00E7\u0131karsan\u0131z yapt\u0131\u011F\u0131n\u0131z de\u011Fi\u015Fiklikler kaybolabilir.",
restore_content:"Restore auto-saved content.",
warning_message:"If you restore the saved content, you will lose all the content that is currently in the editor.\n\nAre you sure you want to restore the saved content?."
},
fullscreen:{
desc:"Tam ekran modunu a\u00E7/kapat"
},
media:{
desc:"T\u00FCmle\u015Fik medya ekle / d\u00FCzenle",
edit:"T\u00FCmle\u015Fik medya d\u00FCzenle"
},
fullpage:{
desc:"Belge \u00F6zellikleri"
},
template:{
desc:"\u00D6ntan\u0131ml\u0131 i\u00E7erik \u015Fablonu kullan"
},
visualchars:{
desc:"G\u00F6rsel karakter kontrol\u00FC a\u00E7\u0131k/kapal\u0131."
},
spellchecker:{
desc:"\u0130mla kontrol\u00FCn\u00FC a\u00E7/kapat",
menu:"\u0130mla kontrol\u00FC ayarlar\u0131",
ignore_word:"S\u00F6zc\u00FC\u011F\u00FC yoksay",
ignore_words:"T\u00FCm\u00FCn\u00FC yoksay",
langs:"Diller",
wait:"L\u00FCtfen bekleyin...",
sug:"\u00D6neriler",
no_sug:"\u00D6neri yok",
no_mpell:"\u0130mla hatas\u0131 bulunamad\u0131."
},
pagebreak:{
desc:"Sayfa sonu ekle."
},
advlist:{
types:"Types",
def:"Default",
lower_alpha:"Lower alpha",
lower_greek:"Lower greek",
lower_roman:"Lower roman",
upper_alpha:"Upper alpha",
upper_roman:"Upper roman",
circle:"Circle",
disc:"Disc",
square:"Square"
}}});
